summaryrefslogtreecommitdiff
path: root/chip/mchp/gpspi.c
diff options
context:
space:
mode:
authorCaveh Jalali <caveh@chromium.org>2021-06-01 22:42:28 -0700
committerCommit Bot <commit-bot@chromium.org>2021-06-03 21:51:02 +0000
commit273bdad8ef38e581895111556e1432bdf3201716 (patch)
tree6c5bac26007a77cab856346160dece195ded1a28 /chip/mchp/gpspi.c
parent14d69d56632b502821aacf5d772e9cde5c9b083e (diff)
downloadchrome-ec-273bdad8ef38e581895111556e1432bdf3201716.tar.gz
COIL: Rename MODULE_SPI_MASTER to MODULE_SPI_CONTROLLER
This renames the MODULE_SPI_MASTER to MODULE_SPI_CONTROLLER. BRANCH=none BUG=b:181607131 TEST=make buildall passes; "compare_build.sh -b all" shows no difference Change-Id: I4d33f57fd82c5b57f111c12387113dc82cebe60b Signed-off-by: Caveh Jalali <caveh@chromium.org> Reviewed-on: https://chromium-review.googlesource.com/c/chromiumos/platform/ec/+/2932466 Reviewed-by: Craig Hesling <hesling@chromium.org> Reviewed-by: Harry Cutts <hcutts@chromium.org> Commit-Queue: Craig Hesling <hesling@chromium.org>
Diffstat (limited to 'chip/mchp/gpspi.c')
-rw-r--r--chip/mchp/gpspi.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/chip/mchp/gpspi.c b/chip/mchp/gpspi.c
index 4edf57ee11..5234db8260 100644
--- a/chip/mchp/gpspi.c
+++ b/chip/mchp/gpspi.c
@@ -212,7 +212,7 @@ int gpspi_transaction_wait(const struct spi_device_t *spi_device)
}
/**
* Enable GPSPI controller and MODULE_SPI_MASTER pins
*
* @param hw_port b[7:4]=1 b[3:0]=0(GPSPI0), 1(GPSPI1)
* @param enable
@@ -227,7 +227,7 @@ int gpspi_enable(int hw_port, int enable)
if ((hw_port != GPSPI0_PORT) && (hw_port != GPSPI1_PORT))
return EC_ERROR_INVAL;
- gpio_config_module(MODULE_SPI_MASTER, (enable > 0));
+ gpio_config_module(MODULE_SPI_CONTROLLER, (enable > 0));
ctrl = (uint32_t)hw_port & 0x0f;
@@ -212,7 +212,7 @@ int gpspi_transaction_wait(const struct spi_device_t *spi_device)
}
/**
- * Enable GPSPI controller and MODULE_SPI_MASTER pins
+ * Enable GPSPI controller and MODULE_SPI_CONTROLLER pins
*
* @param hw_port b[7:4]=1 b[3:0]=0(GPSPI0), 1(GPSPI1)